@@ -49,6 +49,15 @@ public:
 	bool no_sort() const override { return true; }
 };
 
+class FillMonotonicLines : public FillRectilinear
+{
+public:
+    Fill* clone() const override { return new FillMonotonicLines(*this); }
+    ~FillMonotonicLines() override = default;
+    Polylines fill_surface(const Surface *surface, const FillParams &params) override;
+    bool no_sort() const override { return true; }
+};
+
 class FillGrid : public FillRectilinear
 {
 public:
