@@ -74,6 +74,7 @@ bool Print::invalidate_state_by_config_options(const ConfigOptionResolver & /* n
         "duplicate_distance",
         "end_gcode",
         "end_filament_gcode",
+        "external_perimeter_acceleration",
         "extrusion_axis",
         "extruder_clearance_height",
         "extruder_clearance_radius",
@@ -125,10 +126,12 @@ bool Print::invalidate_state_by_config_options(const ConfigOptionResolver & /* n
         "retract_speed",
         "single_extruder_multi_material_priming",
         "slowdown_below_layer_time",
+        "solid_infill_acceleration",
         "standby_temperature_delta",
         "start_gcode",
         "start_filament_gcode",
         "toolchange_gcode",
+        "top_solid_infill_acceleration",
         "thumbnails",
         "thumbnails_format",
         "use_firmware_retraction",
