@@ -21,6 +21,8 @@
 
 #include "I18N.hpp"
 
+#include <libnest2d/tools/benchmark.h>
+
 //! macro used to mark string used at localization,
 //! return same string
 #define L(s) Slic3r::I18N::translate(s)
@@ -215,6 +217,22 @@ struct FaceHash {
     }
 };
 
+static void exclude_neighbors(const Vec3i                &face,
+                              std::vector<bool>          &mask,
+                              const indexed_triangle_set &its,
+                              const VertexFaceIndex      &index,
+                              size_t                      recursions)
+{
+    for (int i = 0; i < 3; ++i) {
+        const auto &neighbors_range = index[face(i)];
+        for (size_t fi_n : neighbors_range) {
+            mask[fi_n] = true;
+            if (recursions > 0)
+                exclude_neighbors(its.indices[fi_n], mask, its, index, recursions - 1);
+        }
+    }
+}
+
 // Create exclude mask for triangle removal inside hollowed interiors.
 // This is necessary when the interior is already part of the mesh which was
 // drilled using CGAL mesh boolean operation. Excluded will be the triangles
@@ -231,15 +249,6 @@ static std::vector<bool> create_exclude_mask(
 
     VertexFaceIndex neighbor_index{its};
 
-    auto exclude_neighbors = [&neighbor_index, &exclude_mask](const Vec3i &face)
-    {
-        for (int i = 0; i < 3; ++i) {
-            const auto &neighbors_range = neighbor_index[face(i)];
-            for (size_t fi_n : neighbors_range)
-                exclude_mask[fi_n] = true;
-        }
-    };
-
     for (size_t fi = 0; fi < its.indices.size(); ++fi) {
         auto &face = its.indices[fi];
 
@@ -249,7 +258,7 @@ static std::vector<bool> create_exclude_mask(
         }
 
         if (exclude_mask[fi]) {
-            exclude_neighbors(face);
+            exclude_neighbors(face, exclude_mask, its, neighbor_index, 1);
             continue;
         }
 
@@ -294,7 +303,7 @@ static std::vector<bool> create_exclude_mask(
 
             if (D_hole < D_tol && std::abs(dot) < normal_angle_tol) {
                 exclude_mask[fi] = true;
-                exclude_neighbors(face);
+                exclude_neighbors(face, exclude_mask, its, neighbor_index, 1);
             }
         }
     }
@@ -880,6 +889,7 @@ void SLAPrint::Steps::merge_slices_and_eval_stats() {
     const double area_fill = printer_config.area_fill.getFloat()*0.01;// 0.5 (50%);
     const double fast_tilt = printer_config.fast_tilt_time.getFloat();// 5.0;
     const double slow_tilt = printer_config.slow_tilt_time.getFloat();// 8.0;
+    const double hv_tilt   = printer_config.high_viscosity_tilt_time.getFloat();// 10.0;
 
     const double init_exp_time = material_config.initial_exposure_time.getFloat();
     const double exp_time      = material_config.exposure_time.getFloat();
@@ -909,7 +919,7 @@ void SLAPrint::Steps::merge_slices_and_eval_stats() {
     // Going to parallel:
     auto printlayerfn = [this,
             // functions and read only vars
-            area_fill, display_area, exp_time, init_exp_time, fast_tilt, slow_tilt, delta_fade_time,
+            area_fill, display_area, exp_time, init_exp_time, fast_tilt, slow_tilt, hv_tilt, material_config, delta_fade_time,
 
             // write vars
             &mutex, &models_volume, &supports_volume, &estim_time, &slow_layers,
@@ -943,7 +953,7 @@ void SLAPrint::Steps::merge_slices_and_eval_stats() {
                             layer.slices().end(),
                             size_t(0),
                             [](size_t a, const SliceRecord &sr) {
-            return a + sr.get_slice(soModel).size();
+            return a + sr.get_slice(soSupport).size();
         });
 
         supports_polygons.reserve(c);
@@ -992,7 +1002,9 @@ void SLAPrint::Steps::merge_slices_and_eval_stats() {
         // Calculation of the slow and fast layers to the future controlling those values on FW
 
         const bool is_fast_layer = (layer_model_area + layer_support_area) <= display_area*area_fill;
-        const double tilt_time = is_fast_layer ? fast_tilt : slow_tilt;
+        const double tilt_time = material_config.material_print_speed == slamsSlow              ? slow_tilt :
+                                 material_config.material_print_speed == slamsHighViscosity     ? hv_tilt   :
+                                 is_fast_layer ? fast_tilt : slow_tilt;
 
         { Lock lck(mutex);
             if (is_fast_layer)
@@ -1013,6 +1025,25 @@ void SLAPrint::Steps::merge_slices_and_eval_stats() {
                 layer_times += exp_time;
             layer_times += tilt_time;
 
+            //// Per layer times (magical constants cuclulated from FW)
+
+            static double exposure_safe_delay_before{ 3.0 };
+            static double exposure_high_viscosity_delay_before{ 3.5 };
+            static double exposure_slow_move_delay_before{ 1.0 };
+
+            if (material_config.material_print_speed == slamsSlow)
+                layer_times += exposure_safe_delay_before;
+            else if (material_config.material_print_speed == slamsHighViscosity)
+                layer_times += exposure_high_viscosity_delay_before;
+            else if (!is_fast_layer)
+                layer_times += exposure_slow_move_delay_before;
+
+            // Increase layer time for "magic constants" from FW
+            layer_times += (
+                l_height * 5  // tower move
+                + 120 / 1000  // Magical constant to compensate remaining computation delay in exposure thread
+            );
+
             layers_times.push_back(layer_times);
             estim_time += layer_times;
         }
