@@ -126,12 +126,12 @@ TEST_CASE("Fill: Pattern Path Length", "[Fill]") {
         filler->angle = 0;
         
         Surface surface(stTop, expolygon);
-        auto flow = Slic3r::Flow(0.69, 0.4, 0.50);
+        auto flow = Slic3r::Flow(0.69f, 0.4f, 0.50f);
 
 		FillParams fill_params;
 		fill_params.density = 1.0;
 		filler->spacing = flow.spacing();
-
+        REQUIRE(!fill_params.use_arachne); // Make this test fail when Arachne is used because this test is not ready for it.
         for (auto angle : { 0.0, 45.0}) {
             surface.expolygon.rotate(angle, Point(0,0));
             Polylines paths = filler->fill_surface(&surface, fill_params);
@@ -435,15 +435,17 @@ bool test_if_solid_surface_filled(const ExPolygon& expolygon, double flow_spacin
 	filler->bounding_box = get_extents(expolygon.contour);
     filler->angle = float(angle);
 
-	Flow flow(flow_spacing, 0.4, flow_spacing);
+	Flow flow(float(flow_spacing), 0.4f, float(flow_spacing));
 	filler->spacing = flow.spacing();
 
 	FillParams fill_params;
 	fill_params.density = float(density);
 	fill_params.dont_adjust = false;
 
-	Surface surface(stBottom, expolygon);
-	Slic3r::Polylines paths = filler->fill_surface(&surface, fill_params);
+    Surface surface(stBottom, expolygon);
+    if (fill_params.use_arachne) // Make this test fail when Arachne is used because this test is not ready for it.
+        return false;
+    Slic3r::Polylines paths = filler->fill_surface(&surface, fill_params);
 
     // check whether any part was left uncovered
     Polygons grown_paths;
@@ -456,7 +458,7 @@ bool test_if_solid_surface_filled(const ExPolygon& expolygon, double flow_spacin
     });
 
 	// Shrink the initial expolygon a bit, this simulates the infill / perimeter overlap that we usually apply.
-    ExPolygons uncovered = diff_ex(offset(expolygon, - float(0.2 * scale_(flow_spacing))), grown_paths, true);
+    ExPolygons uncovered = diff_ex(offset(expolygon, - float(0.2 * scale_(flow_spacing))), grown_paths, ApplySafetyOffset::Yes);
 
     // ignore very small dots
     const double scaled_flow_spacing = std::pow(scale_(flow_spacing), 2);
